NoFOMO
搜索 中EN 登录 注册

最高第 2 名 现在第 3 名

Jarred Sumner介绍Bun AOT裁剪

Jarred Sumner 介绍Bun AOT的--trim选项,可将macOS上HTTP服务器二进制从89MB减至25MB。

名次变化

要点

  • 据 @jarredsumner 称,Bun AOT 新增 `--trim` 选项,可从编译后的二进制文件中删除 Bun 未使用的部分。
  • 在 macOS 上,使用 Bun.serve 的 HTTP 服务器的二进制文件从 89 MB 降至 25 MB。
  • @jarredsumner 表示,`--trim` 的另一个原因是安全,通过移除未使用的功能和库来减少攻击面。

要点和反应摘要由 AI 依据本页推文整理,请以原推为准。 我们怎么用 AI

原推

Jarred Sumner @jarredsumner 19.6万 粉丝

Bun AOT also introduces `--trim` which deletes unused parts of Bun from the compiled binary On macOS, a binary that uses Bun.serve’s HTTP server goes from 89 MB to 25 MB https://t.co/BRVetpDKwW
推文配图
445点赞 9转发 25回复 1.2万浏览

在 X 上查看 收藏

同一事件,其他人怎么说

1 条
  1. Jarred Sumner @jarredsumner 47

    Jarred Sumner 称移除二进制中未用功能可减少攻击面、提升安全性。

    在 X 上查看

X 上的热门回复

X 上的反应: 回复里有人追问为何还有 25 MB,也有人开玩笑。原推作者回应称,JavaScriptCore 和 Bun 优先优化速度而非二进制体积,并发 GC 和对象模型会带来代码体积开销,但仍有改进空间。

登录后查看 X 上的 3 条热门回复

来自 @jarredsumner, @zahaibakber, @itsrealakm 等,已过滤广告,附中英文翻译。

免费注册 已有账号?登录

讨论 0

还没有人讨论,来说第一句。

推荐信源

觉得我们漏了哪个一手信源,或者该关注什么话题?告诉我们。审核通过后,所有人的榜单都会覆盖到它。

@用户名,或者主页链接